==> Paws-0.24.tar.gz: Paws-0.24/lib/Paws/IAM/GetAccessKeyLastUsed.pm <==

package Paws::IAM::GetAccessKeyLastUsed;
  use Moose;
  has AccessKeyId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetAccessKeyLastUsed');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::IAM::GetAccessKeyLastUsedResponse');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'GetAccessKeyLastUsedResult');
1;

### main pod documentation begin ###

=head1 NAME

Paws::IAM::GetAccessKeyLastUsed - Arguments for method GetAccessKeyLastUsed on Paws::IAM

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetAccessKeyLastUsed on the 
AWS Identity and Access Management service. Use the attributes of this class
as arguments to method GetAccessKeyLastUsed.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetAccessKeyLastUsed.

As an example:

  $service_obj->GetAccessKeyLastUsed(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> AccessKeyId => Str

The identifier of an access key.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetAccessKeyLastUsed in L<Paws::IAM>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.26.tar.gz: Paws-0.26/lib/Paws/IAM/GetAccessKeyLastUsed.pm <==

package Paws::IAM::GetAccessKeyLastUsed;
  use Moose;
  has AccessKeyId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetAccessKeyLastUsed');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::IAM::GetAccessKeyLastUsedResponse');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'GetAccessKeyLastUsedResult');
1;

### main pod documentation begin ###

=head1 NAME

Paws::IAM::GetAccessKeyLastUsed - Arguments for method GetAccessKeyLastUsed on Paws::IAM

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetAccessKeyLastUsed on the 
AWS Identity and Access Management service. Use the attributes of this class
as arguments to method GetAccessKeyLastUsed.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetAccessKeyLastUsed.

As an example:

  $service_obj->GetAccessKeyLastUsed(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> AccessKeyId => Str

The identifier of an access key.

The regex pattern for this parameter is a string of characters that can
consist of any upper or lowercased letter or digit.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetAccessKeyLastUsed in L<Paws::IAM>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
